==> rekonq_0.5.0.orig.tar.bz2: rekonq-0.5.0/src/settings/appearancewidget.h <==
/* ============================================================
*
* This file is a part of the rekonq project
*
* Copyright (C) 2010 by Andrea Diamantini <adjam7 at gmail dot com>
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License or (at your option) version 3 or any later version
* accepted by the membership of KDE e.V. (or its successor approved
* by the membership of KDE e.V.), which shall act as a proxy
* defined in Section 14 of version 3 of the license.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
* ============================================================ */


#ifndef APPEARANCE_WIDGET_H
#define APPEARANCE_WIDGET_H


// Rekonq Includes
#include "rekonq_defines.h"

// Ui Includes
#include "ui_settings_appearance.h"

// Qt Includes
#include <QtGui/QWidget>


class AppearanceWidget : public QWidget, private Ui::appearance
{
    Q_OBJECT

public:
    AppearanceWidget(QWidget *parent = 0);

    void save();
    bool changed();

signals:
    void changed(bool);

private slots:
    void hasChanged();
    
    void slotStandardFont(const QFont &);
    void slotFixedFont(const QFont &);
    void slotSerifFont(const QFont &);
    void slotSansSerifFont(const QFont &);
    void slotCursiveFont(const QFont &);
    void slotFantasyFont(const QFont &);
                    
private:
    bool _changed;
    
    QString reFont[6];
    
};

#endif // APPEARANCE_WIDGET_H

==> rekonq_0.6.1.orig.tar.bz2: rekonq-0.6.1/src/settings/appearancewidget.h <==
/* ============================================================
*
* This file is a part of the rekonq project
*
* Copyright (C) 2010 by Andrea Diamantini <adjam7 at gmail dot com>
*
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License or (at your option) version 3 or any later version
* accepted by the membership of KDE e.V. (or its successor approved
* by the membership of KDE e.V.), which shall act as a proxy
* defined in Section 14 of version 3 of the license.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
* ============================================================ */


#ifndef APPEARANCE_WIDGET_H
#define APPEARANCE_WIDGET_H


// Rekonq Includes
#include "rekonq_defines.h"

// Ui Includes
#include "ui_settings_appearance.h"

// Qt Includes
#include <QtGui/QWidget>


class AppearanceWidget : public QWidget, private Ui::appearance
{
    Q_OBJECT

public:
    AppearanceWidget(QWidget *parent = 0);

    void save();
    bool changed();
    bool isDefault();
    
signals:
    void changed(bool);

private slots:
    void hasChanged();
                    
private:
    bool _changed;
};

#endif // APPEARANCE_WIDGET_H
